﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

// VMdemoWinForms
// Example of an approach to ViewModel for scientific software, using WPF
// Released for educational purposes, without warranty or restrictions.
// Compliments of:
//    Michael A. Covington, Ph.D., Consultant
//    Covington Innovations
//    http://www.covingtoninnovations.com/michael

// Key idea:
//
// The purpose of the ViewModel paradigm is to restrict interaction between
// the user interface (Form1, the "view") and the computation engine 
// (the "model" in older nomenclature).  See the comments in Form1ViewModel.cs.
//
// See also the comments in the other .cs files.


namespace VMdemoWinForms
{
    public partial class Form1 : Form
    {
        Form1ViewModel vm;

        #region Main window constructor

        public Form1()
        {
            InitializeComponent();
            vm = new Form1ViewModel(this);
        }

        #endregion

        #region Event handlers for user input

        private void buttonStart_Click(object sender, EventArgs e)
        {
            // Disable warning 4014 so compiler won't tell us to use "await".
            // Launching asynchronously is intentional here.
            #pragma warning disable 4014
            vm.LaunchComputation();
            #pragma warning restore 4014        
        }
        
        private void buttonCancel_Click(object sender, EventArgs e)
        {
            vm.CancelComputation();
        }

        private void textBoxSeconds_TextChanged(object sender, EventArgs e)
        {
            vm.UpdateGuiAppearance();
            // Start button depends on whether there's a valid integer in the box.
        }

        #endregion

    }
}
